@@ -25,7 +25,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 require Exporter;
 require DynaLoader;
 
-our $VERSION='0.76_01';
+our $VERSION='0.76_02';
 
 @ISA = qw(Exporter DynaLoader);
 %EXPORT_TAGS = (nodetypes => [qw(BTAST_STRING BTAST_MACRO BTAST_NUMBER)],
@@ -52,6 +52,7 @@ our $VERSION='0.76_01';
 use Encode 'encode', 'decode';
 use Unicode::Normalize;
 
+
 sub _process_result {
   no strict 'refs';
   my ( $self, $result, $encoding, $norm ) = @_;
@@ -285,6 +286,12 @@ bootstrap Text::BibTeX;
 initialize();                            # these are both XS functions
 END { &cleanup; }
 
+# This can't go in a BEGIN because of the .XS bootstrapping mechanism
+for my $month (qw.january february march april may june
+             july august september october november december.) {
+    add_macro_text(substr($month, 0, 3), ucfirst($month));
+}
+
 
 =head1 EXPORTS
 
@@ -714,7 +721,8 @@ takes no action.
 
 =item delete_all_macros ()
 
-Deletes all macros from the macro table.
+Deletes all macros from the macro table, even the predefined month
+names.
 
 =item macro_length (MACRO)
 
